package at.ac.uibk.gitsearch.web.rest;

import static org.assertj.core.api.Assertions.assertThat;
import static org.springframework.security.test.web.servlet.request.SecurityMockMvcRequestPostProcessors.csrf;

import at.ac.uibk.gitsearch.GitsearchApp;
import at.ac.uibk.gitsearch.service.EditorialPagesService;
import at.ac.uibk.gitsearch.service.EditorialPagesService.HelpContentTree;
import java.util.concurrent.TimeUnit;
import org.junit.jupiter.api.Timeout;
import org.junit.jupiter.api.extension.ExtendWith;
import org.junit.jupiter.params.ParameterizedTest;
import org.junit.jupiter.params.provider.ValueSource;
import org.mockito.junit.jupiter.MockitoExtension;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.autoconfigure.web.servlet.AutoConfigureMockMvc;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.http.MediaType;
import org.springframework.test.web.servlet.MockMvc;
import org.springframework.test.web.servlet.request.MockMvcRequestBuilders;

@SpringBootTest(classes = GitsearchApp.class)
@ExtendWith(MockitoExtension.class)
@AutoConfigureMockMvc
class EditorialPagesResourceIT {

    private static final Logger LOGGER = LoggerFactory.getLogger(EditorialPagesResourceIT.class);

    private static final String ENTITY_API_URL = "/api/pages";

    @Autowired
    private MockMvc mockMvc;

    @ParameterizedTest
    @ValueSource(strings = { EditorialPagesService.DE_LANGTAG, EditorialPagesService.EN_LANGTAG })
    @Timeout(value = 60, unit = TimeUnit.SECONDS) // gitlab may respond slowly
    void getHelpContentTreeTest(String lang) throws Exception {
        mockMvc
            .perform(
                MockMvcRequestBuilders
                    .get(ENTITY_API_URL + "/helpTree/" + lang)
                    .with(csrf().asHeader())
                    .contentType(MediaType.APPLICATION_JSON)
            )
            .andExpect(
                TestUtil.testResult(
                    HelpContentTree.class,
                    tree -> {
                        LOGGER.info("The tree is: {} ", tree);
                        assertThat(tree).isNotNull();
                        assertThat(tree.getChildren()).isNotEmpty();
                    }
                )
            );
    }
}
